pub struct Keyframe { /* private fields */ }Expand description
A property snapshot stored at a normalized keyframe offset.
Implementations
Sourceimpl Keyframe
impl Keyframe
Sourcepub fn new(offset: f32, snapshot: PropertySnapshot) -> Self
pub fn new(offset: f32, snapshot: PropertySnapshot) -> Self
Creates a keyframe with a normalized offset and composition-sorted snapshot.
Sourcepub const fn snapshot(&self) -> &PropertySnapshot
pub const fn snapshot(&self) -> &PropertySnapshot
Returns a reference to the property snapshot at this keyframe.