pub struct PropertyKey { /* private fields */ }Expand description
Stable property identity.
The namespace/name pair is used instead of a central enum so downstream code can declare additional properties without modifying this crate.
Example
use aura_anim_iced::property::{PropertyKey, PropertySpec, Scalar};
const TOAST_Y: PropertySpec<Scalar> =
PropertySpec::new(PropertyKey::new("app", "toast-y"), 21);
assert_eq!(TOAST_Y.raw().key().name(), "toast-y");Implementations