pub enum AnimationPlaybackState {
Playing,
Paused,
Canceled,
Completed,
}Expand description
Playback state tracked for an active runtime entry.
Variants
Playing
The animation can advance on runtime ticks.
Paused
The animation is held at its current elapsed position.
Canceled
The animation has been canceled and should stop producing snapshots.
Completed
The animation reached completion.