pub struct AnimationRegistration { /* private fields */ }Expand description
Output produced when an animation is registered with the runtime.
Implementations
Sourceimpl AnimationRegistration
impl AnimationRegistration
Sourcepub const fn handle(&self) -> AnimationHandle
pub const fn handle(&self) -> AnimationHandle
Returns the registered animation handle.
Sourcepub const fn state(&self) -> AnimationPlaybackState
pub const fn state(&self) -> AnimationPlaybackState
Returns the initial playback state.
Sourcepub const fn properties(&self) -> Option<&PropertySnapshot>
pub const fn properties(&self) -> Option<&PropertySnapshot>
Returns the initial property snapshot produced during registration.
Sourcepub const fn completed_at(&self) -> Option<Duration>
pub const fn completed_at(&self) -> Option<Duration>
Returns the completion timestamp for animations completed at registration.