pub struct AnimationRuntime<C = SystemClock> { /* private fields */ }Expand description
Runtime state owned by an Iced application.
Example
use aura_anim_iced::{
AnimationRuntime, AnimationTargetId, KeyframesBuilder, Timing, property,
};
let mut runtime = AnimationRuntime::new();
let target = AnimationTargetId::new();
let registration = runtime.register_keyframes(
target,
KeyframesBuilder::new()
.with_timing(Timing::new(100.0))
.at(0.0, (property::OPACITY, 0.0))
.at(1.0, (property::OPACITY, 1.0))
.finish(),
);
assert!(runtime.should_subscribe());Implementations
Sourceimpl AnimationRuntime<TestClock>
impl AnimationRuntime<TestClock>
Sourceimpl<C: AnimationClock> AnimationRuntime<C>
impl<C: AnimationClock> AnimationRuntime<C>
Sourcepub fn with_clock(clock: C) -> Self
pub fn with_clock(clock: C) -> Self
Creates an empty runtime with a custom clock.
Sourcepub fn register_keyframes(
&mut self,
target: AnimationTargetId,
keyframes: Keyframes,
) -> AnimationRegistration
pub fn register_keyframes( &mut self, target: AnimationTargetId, keyframes: Keyframes, ) -> AnimationRegistration
Registers keyframes and returns their initial runtime output.
Sourcepub fn register_timeline(
&mut self,
target: AnimationTargetId,
timeline: Timeline,
) -> AnimationRegistration
pub fn register_timeline( &mut self, target: AnimationTargetId, timeline: Timeline, ) -> AnimationRegistration
Registers a timeline and returns its initial runtime output.
Sourcepub fn tick(&mut self) -> AnimationTick
pub fn tick(&mut self) -> AnimationTick
Advances active animations and returns a view-ready aggregated snapshot.
Sourcepub fn tick_into(&mut self, output: &mut AnimationTick)
pub fn tick_into(&mut self, output: &mut AnimationTick)
Advances active animations into a reusable tick output.
Sourcepub fn cancel_target(&mut self, target: AnimationTargetId)
pub fn cancel_target(&mut self, target: AnimationTargetId)
Cancels and removes all active animations registered for target.
Sourcepub fn seek_target(&mut self, target: AnimationTargetId, pos: Duration)
pub fn seek_target(&mut self, target: AnimationTargetId, pos: Duration)
Seeks all active animations registered for target.
Sourcepub fn pause_target(&mut self, target: AnimationTargetId)
pub fn pause_target(&mut self, target: AnimationTargetId)
Pauses all active animations registered for target.
Sourcepub fn cancel(
&mut self,
target: AnimationTargetId,
handle: AnimationHandle,
) -> bool
pub fn cancel( &mut self, target: AnimationTargetId, handle: AnimationHandle, ) -> bool
Cancels and removes one animation when handle belongs to target.
Returns true when an entry was removed.
Sourcepub fn seek(
&mut self,
target: AnimationTargetId,
handle: AnimationHandle,
pos: Duration,
) -> bool
pub fn seek( &mut self, target: AnimationTargetId, handle: AnimationHandle, pos: Duration, ) -> bool
Seeks one animation when handle belongs to target.
Returns true when an entry was found and updated.
Sourcepub fn pause(
&mut self,
target: AnimationTargetId,
handle: AnimationHandle,
) -> bool
pub fn pause( &mut self, target: AnimationTargetId, handle: AnimationHandle, ) -> bool
Pauses one animation when handle belongs to target.
Returns true when an entry was found and updated.
Sourceimpl<C> AnimationRuntime<C>
impl<C> AnimationRuntime<C>
Sourcepub const fn motion_policy(&self) -> TickPolicy
pub const fn motion_policy(&self) -> TickPolicy
Returns the current motion policy.
Sourcepub const fn set_motion_policy(&mut self, motion_policy: TickPolicy)
pub const fn set_motion_policy(&mut self, motion_policy: TickPolicy)
Replaces the current motion policy.
Sourcepub fn active_count(&self) -> usize
pub fn active_count(&self) -> usize
Returns the number of active animation entries.
Sourcepub fn should_tick(&self) -> bool
pub fn should_tick(&self) -> bool
Returns whether the runtime has entries that should receive animation ticks.
Sourcepub fn should_subscribe(&self) -> bool
pub fn should_subscribe(&self) -> bool
Returns whether an Iced subscription should keep producing animation ticks.