pub enum TimelineStep {
Track(Track),
Sequence(Sequence),
Parallel(Parallel),
Hold(Hold),
}Expand description
A timeline step that can contribute duration to a timeline.
Variants
Track(Track)
A keyframe track.
Sequence(Sequence)
A sequential group of steps.
Parallel(Parallel)
A parallel group of steps.
Hold(Hold)
A silent hold segment.
Implementations
Sourceimpl TimelineStep
impl TimelineStep
Sourcepub fn total_duration(&self) -> Option<Duration>
pub fn total_duration(&self) -> Option<Duration>
Returns the finite total duration of this step, or None for infinite tracks.
Sourcepub fn sample_at(&self, offset: impl Into<Duration>) -> Option<PropertySnapshot>
pub fn sample_at(&self, offset: impl Into<Duration>) -> Option<PropertySnapshot>
Samples this step at local timeline offset.
Sourcepub fn completion_snapshot(&self) -> Option<PropertySnapshot>
pub fn completion_snapshot(&self) -> Option<PropertySnapshot>
Samples the final visual state for this step.