pub struct Parallel { /* private fields */ }Expand description
A parallel timeline group.
Implementations
Sourceimpl Parallel
impl Parallel
Sourcepub fn from_steps(steps: impl IntoIterator<Item = TimelineStep>) -> Self
pub fn from_steps(steps: impl IntoIterator<Item = TimelineStep>) -> Self
Creates a parallel group from steps.
Sourcepub fn steps(&self) -> &[TimelineStep]
pub fn steps(&self) -> &[TimelineStep]
Returns the parallel steps in insertion order.
Sourcepub fn push_step(&mut self, step: impl Into<TimelineStep>)
pub fn push_step(&mut self, step: impl Into<TimelineStep>)
Appends a timeline step.
Sourcepub fn then(self, step: impl Into<TimelineStep>) -> Self
pub fn then(self, step: impl Into<TimelineStep>) -> Self
Appends a timeline step and returns the updated parallel group.
Sourcepub fn parallel_step(self, parallel: Parallel) -> Self
pub fn parallel_step(self, parallel: Parallel) -> Self
Appends a nested parallel group.
Sourcepub fn total_duration(&self) -> Option<Duration>
pub fn total_duration(&self) -> Option<Duration>
Returns the finite maximum step duration, or None if any step is infinite.
Sourcepub fn sample_at(&self, offset: impl Into<Duration>) -> Option<PropertySnapshot>
pub fn sample_at(&self, offset: impl Into<Duration>) -> Option<PropertySnapshot>
Samples this parallel group at local timeline offset.
Sourcepub fn completion_snapshot(&self) -> Option<PropertySnapshot>
pub fn completion_snapshot(&self) -> Option<PropertySnapshot>
Samples the final visual state of all child steps.