FillMode

Enum FillMode 

pub enum FillMode {
    None,
    Backwards,
    Forwards,
    Both,
}
How samples outside the active interval should be filled.

Variants



None

Do not fill before or after the active interval.



Backwards

Fill with the first active sample before the delay completes.



Forwards

Fill with the final active sample after completion.



Both

Fill both before the delay and after completion.