pub enum TimingSampleState {
BeforeStart,
Active,
AfterEnd,
BackwardsFill,
ForwardsFill,
}Expand description
The sampling state produced by fill-mode-aware timing normalization.
Variants
BeforeStart
Elapsed time is before the active interval and no sample should be emitted.
Active
Elapsed time is inside the active interval.
AfterEnd
Elapsed time is after the active interval and no sample should be emitted.
BackwardsFill
Elapsed time is before the active interval and should emit the first sample.
ForwardsFill
Elapsed time is after the active interval and should emit the final sample.
Implementations