pub struct KeyframesBuilder { /* private fields */ }Expand description
Builder that collects offset-keyed snapshots before compiling them into per-property tracks.
Duplicate offsets are merged as snapshots are inserted. If the same property appears more than once at an offset, the later value wins.
Implementations
Sourceimpl KeyframesBuilder
impl KeyframesBuilder
Sourcepub const fn timing(&self) -> &Timing
pub const fn timing(&self) -> &Timing
Returns the timing that will be attached to the finished keyframes.
Sourcepub const fn with_timing(self, timing: Timing) -> Self
pub const fn with_timing(self, timing: Timing) -> Self
Sets the timing attached to the finished keyframes.
Sourcepub fn at(self, offset: f32, snapshot: impl Into<PropertySnapshot>) -> Self
pub fn at(self, offset: f32, snapshot: impl Into<PropertySnapshot>) -> Self
Inserts a property snapshot at a normalized offset.
Sourcepub fn translation(self, offset: f32, x: f32, y: f32) -> Self
pub fn translation(self, offset: f32, x: f32, y: f32) -> Self
Inserts a translation keyframe.
Sourcepub fn background_color(self, offset: f32, value: Color) -> Self
pub fn background_color(self, offset: f32, value: Color) -> Self
Inserts a background color keyframe.
Sourcepub fn border_color(self, offset: f32, value: Color) -> Self
pub fn border_color(self, offset: f32, value: Color) -> Self
Inserts a border color keyframe.
Sourcepub fn text_color(self, offset: f32, value: Color) -> Self
pub fn text_color(self, offset: f32, value: Color) -> Self
Inserts a text color keyframe.
Sourcepub fn push_at(&mut self, offset: f32, snapshot: impl Into<PropertySnapshot>)
pub fn push_at(&mut self, offset: f32, snapshot: impl Into<PropertySnapshot>)
Inserts a property snapshot at a normalized offset.