pub struct Timing { /* private fields */ }Expand description
Timing state for an animation track or timeline step.
Example
use aura_anim_iced::timing::{
Delay, Direction, Easing, FillMode, Timing, TimingSampleState,
};
let timing = Timing::new(200.0)
.with_delay(Delay::from_millis(50.0))
.with_direction(Direction::Alternate)
.with_fill_mode(FillMode::Both)
.with_easing(Easing::EaseOut)
.with_iterations(2);
let before = timing.normalize_elapsed(25.0);
let active = timing.normalize_elapsed(100.0);
assert_eq!(before.sample_state, TimingSampleState::BackwardsFill);
assert!(active.has_sample());Implementations
Sourceimpl Timing
impl Timing
Sourcepub const fn iterations(&self) -> IterationCount
pub const fn iterations(&self) -> IterationCount
Returns the number of iterations of the timing.
Sourcepub const fn playback_rate(&self) -> f64
pub const fn playback_rate(&self) -> f64
Returns the playback rate of the timing.
Sourcepub const fn with_delay(self, delay: Delay) -> Self
pub const fn with_delay(self, delay: Delay) -> Self
Sets the start delay.
Sourcepub const fn with_direction(self, direction: Direction) -> Self
pub const fn with_direction(self, direction: Direction) -> Self
Sets the playback direction.
Sourcepub const fn with_fill_mode(self, fill_mode: FillMode) -> Self
pub const fn with_fill_mode(self, fill_mode: FillMode) -> Self
Sets the fill mode.
Sourcepub const fn with_easing(self, easing: Easing) -> Self
pub const fn with_easing(self, easing: Easing) -> Self
Sets the easing curve.
Sourcepub fn with_iterations(self, iterations: impl Into<IterationCount>) -> Self
pub fn with_iterations(self, iterations: impl Into<IterationCount>) -> Self
Sets the iteration count.
Sourcepub fn with_playback_rate(self, playback_rate: f64) -> Self
pub fn with_playback_rate(self, playback_rate: f64) -> Self
Sets the playback rate.
Sourcepub fn active_duration(self) -> Option<Duration>
pub fn active_duration(self) -> Option<Duration>
Returns the total active duration when the timing has a finite length.
Sourcepub fn total_duration(self) -> Option<Duration>
pub fn total_duration(self) -> Option<Duration>
Returns the total duration including delay when finite.
Sourcepub fn normalize_elapsed(self, elapsed_ms: f64) -> NormalizedTiming
pub fn normalize_elapsed(self, elapsed_ms: f64) -> NormalizedTiming
Normalizes elapsed milliseconds into active timing coordinates.